@@ -1,4 +1,3 @@
-#' @importFrom purrr walk2
 
 download_abs <- function(urls,
                          path,
@@ -13,30 +12,26 @@ download_abs <- function(urls,
 
   filenames <- file.path(path, basename(urls))
 
-  dl_file <- function(url, filename, show_progress_bars, handle) {
-    if (show_progress_bars) {
-      message("Downloading ", url)
-    }
-
-    curl::curl_download(
-      url = url,
-      destfile = filename,
-      mode = "wb",
-      quiet = !show_progress_bars,
-      handle = handle
-    )
-  }
-
-  handle <- curl::new_handle()
-  curl::handle_setheaders(handle,
-                          "User-Agent" = readabs_user_agent)
-
   purrr::walk2(.x = urls,
                .y = filenames,
                .f = dl_file,
-               show_progress_bars = show_progress_bars,
-               handle = handle)
-
+               quiet = !show_progress_bars)
 
   return(TRUE)
 }
+
+dl_file <- function(url, destfile, quiet = TRUE) {
+
+  if (isFALSE(quiet)) {
+    message("Downloading ", url)
+  }
+
+  utils::download.file(
+    url = url,
+    destfile = destfile,
+    mode = "wb",
+    quiet = quiet,
+    headers = readabs_header,
+    cacheOK = FALSE
+  )
+}
