@@ -26,12 +26,12 @@
 #'
 #' # Create a tibble called 'cpi' that contains the CPI index
 #' # numbers for each quarter
-#'
-#' \donttest{cpi <- read_cpi()}
+#' \donttest{
+#' cpi <- read_cpi()
+#' }
 #'
 #' # This tibble can now be joined to another to help streamline the process of
 #' # deflating nominal values.
-#'
 #' @importFrom dplyr filter select
 #'
 #' @export
@@ -40,7 +40,6 @@ read_cpi <- function(path = Sys.getenv("R_READABS_PATH", unset = tempdir()),
                      show_progress_bars = TRUE,
                      check_local = FALSE,
                      retain_files = FALSE) {
-
   if (!is.logical(retain_files)) {
     stop("`retain_files` must be either `TRUE` or `FALSE`.")
   }
@@ -50,25 +49,30 @@ read_cpi <- function(path = Sys.getenv("R_READABS_PATH", unset = tempdir()),
   }
 
   if (retain_files == TRUE & !is.character(path)) {
-    stop("If `retain_files` is `TRUE`,",
-         " you must specify a valid file path in `path`.")
+    stop(
+      "If `retain_files` is `TRUE`,",
+      " you must specify a valid file path in `path`."
+    )
   }
 
-  series = value = date = cpi = NULL
+  series <- value <- date <- cpi <- NULL
 
-  cpi_raw <- read_abs(cat_no = "6401.0",
-                      tables = 1,
-                      retain_files = retain_files,
-                      check_local = check_local,
-                      show_progress_bars = show_progress_bars,
-                      path = path)
+  cpi_raw <- read_abs(
+    cat_no = "6401.0",
+    tables = 1,
+    retain_files = retain_files,
+    check_local = check_local,
+    show_progress_bars = show_progress_bars,
+    path = path
+  )
 
   x <- cpi_raw %>%
     dplyr::filter(
-      series == "Index Numbers ;  All groups CPI ;  Australia ;") %>%
+      series == "Index Numbers ;  All groups CPI ;  Australia ;"
+    ) %>%
     dplyr::select(date,
-                  cpi = value)
+      cpi = value
+    )
 
   x
-
 }
