@@ -1,13 +1,9 @@
 
-check_abs_site <- function() {
-  if (is.null(curl::nslookup("abs.gov.au", error = FALSE))) {
-    skip("ABS Time Series Directory not available")
-  }
-}
 
 test_that("download_abs() fetches files", {
   skip_on_cran()
-  check_abs_site()
+  skip_if_offline()
+  check_abs_connection()
 
   xml_urls <- form_abs_tsd_url(
     cat_no = "6202.0",
@@ -16,8 +12,7 @@ test_that("download_abs() fetches files", {
   )
 
   xml_dfs <- purrr::map_dfr(xml_urls,
-    .f = get_abs_xml_metadata,
-    issue = "latest"
+    .f = get_abs_xml_metadata
   )
 
   urls <- unique(xml_dfs$TableURL)
